/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

/*
 * XV2.21 Compression Handling Routines Author:    John Bradley, University
 * of Pennsylvania (bradley@cis.upenn.edu)
 */


#ifndef _NO_PROTO
int             CompressionTest (char *fullname, char *filename);
int             CompressionCmd (char *tmpdir, char *filename, char *fullname, char *basefname, char *CompressCommand);
void             CompressionCleanUp (char *filename);
int             ImportCmd (char *filename, int ImportType);
int 		ExtensionTest(char *filename);
void 		ImportCleanUp(char *filename);
int 		BlankEnd(char *fullname);
int 		MakeCompressed(char *fullname,int type);
#else
int             CompressionTest ();
int             CompressionCmd ();
void             CompressionCleanUp ();
int             ImportCmd ();
int 		ExtensionTest();
void 		ImportCleanUp();
int 		BlankEnd();
int 		MakeCompressed();
#endif
